@@ -2,10 +2,11 @@ import os
 import re
 import sys
 from argparse import ArgumentParser
-from .setuptools import get_file_content
+from setuptools import get_file_content
 
 
-def get_substring(regexp_pattern: str, line: str, output_format: str = None, join_with: str = None) -> str:
+def get_substring(regexp_pattern: str, line: str, output_format: str = None, join_with: str = None,
+                  reverse_matches: bool = False) -> str:
     def _join_matches_into_list(_matches: list, _append_list: list = None) -> list:
         if _append_list is None:
             _append_list = list()
@@ -18,8 +19,12 @@ def get_substring(regexp_pattern: str, line: str, output_format: str = None, joi
 
     if not join_with:
         join_with = "\t"
+    import sys; sys.path.append("/tmp/_pydbg/pycharm-debug-py3k.egg"); import pydevd; pydevd.settrace('localhost', port=7878, stdoutToServer=True, stderrToServer=True)
     matches = re.findall(regexp_pattern, line)
+    matches = matches[0] if matches else []
     if matches:
+        if reverse_matches:
+            matches.reverse()
         if output_format:
             return output_format.format(*_join_matches_into_list(matches))
         return join_with.join(matches)
@@ -75,6 +80,7 @@ def _handle_args() -> tuple:
     parser.add_argument("-s", "--strip", dest="strip", default=False, action="store_true", help="Strip spaces from left and right side of result")
     parser.add_argument("-j", "--join-results", dest="join_results", type=str, help="Join all results with specified char(s)")
     parser.add_argument("--join-matches", dest="join_matches", type=str, help="Join more regexp matches with specified char(s). Default is TAB \\t")
+    parser.add_argument("--reverse-matches", dest="reverse_matches", default=False, action="store_true", help="Reverse order of matches")
     parser.add_argument("--split", dest="split", type=str, help="Split result by specified string.")
     parser.add_argument("--split-after", dest="split_after", type=int, help="Split result by specified string after each X match. For example split after every 5th ',' uccurence.")
     parser.add_argument("-f", "--find-replace", dest="find_replace", type=str, help="Find string and replace it with another string. It have to be defined in following format \"find::replace\"")
@@ -89,7 +95,8 @@ def main():
     result_list = []
     for line in sys.stdin:
         try:
-            result = get_substring(args.regexp_pattern, line, output_format=args.output_format, join_with=args.join_matches)
+            result = get_substring(args.regexp_pattern, line, output_format=args.output_format, join_with=args.join_matches,
+                                   reverse_matches=args.reverse_matches)
             result = postprocess(result, args.strip, args.cut_left, args.cut_right, args.l_wrap, args.r_wrap,
                                  args.find_replace, args.split, args.split_after)
             if args.join_results:
